@@ -3,6 +3,7 @@
 from starlette import status
 
 from rowantree.common.sdk import demand_env_var
+from rowantree.contracts import FeatureType
 
 from ...contracts.dto.request_status_codes import RequestStatusCodes
 from ...contracts.dto.wrapped_request import WrappedRequest
@@ -14,15 +15,15 @@ from ..abstract_command import AbstractCommand
 class UserFeaturesGetCommand(AbstractCommand):
     """
     User Features Get Command
-    Gets the unique list of user features.
+    Gets the unique set of user features.
 
     Methods
     -------
-    execute(self, user_guid: str) -> FeaturesGetResponse
+    execute(self, user_guid: str) -> set[FeatureType]
         Executes the command.
     """
 
-    def execute(self, user_guid: str) -> FeaturesGetResponse:
+    def execute(self, user_guid: str) -> set[FeatureType]:
         """
         Executes the command.
 
@@ -33,8 +34,8 @@ class UserFeaturesGetCommand(AbstractCommand):
 
         Returns
         -------
-        user_features: FeaturesGetResponse
-            A unique list of user features.
+        user_features: set[FeatureType]
+            A unique set of user features.
         """
 
         request: WrappedRequest = WrappedRequest(
@@ -43,4 +44,5 @@ class UserFeaturesGetCommand(AbstractCommand):
             statuses=RequestStatusCodes(allow=[status.HTTP_200_OK], reauth=[status.HTTP_401_UNAUTHORIZED], retry=[]),
         )
         response: dict = self.wrapped_request(request=request)
-        return FeaturesGetResponse.parse_obj(response)
+        features_get_response: FeaturesGetResponse = FeaturesGetResponse.parse_obj(response)
+        return features_get_response.features
