@@ -1,7 +1,5 @@
 """ Merchant Transform Request Definition """
-
-from pydantic import BaseModel
-
+from rowantree.common.sdk import BaseModel
 from rowantree.contracts import StoreType
 
 
