@@ -1,6 +1,5 @@
 """ User Income Set Request Definition """
-from pydantic import BaseModel
-
+from rowantree.common.sdk import BaseModel
 from rowantree.contracts import StoreType
 
 
