@@ -1,7 +1,6 @@
 """ Active Feature Response Definition """
 
-from pydantic import BaseModel
-
+from rowantree.common.sdk import BaseModel
 from rowantree.contracts import FeatureType
 
 
