@@ -1,6 +1,5 @@
 """ FeaturesGetResponse Definition """
-from pydantic import BaseModel
-
+from rowantree.common.sdk import BaseModel
 from rowantree.contracts import FeatureType
 
 
