@@ -1,7 +1,6 @@
 """ MerchantTransformsGetResponse Definition """
 
-from pydantic import BaseModel
-
+from rowantree.common.sdk import BaseModel
 from rowantree.contracts import StoreType
 
 
