@@ -1,6 +1,6 @@
 """ PopulationGetResponse Definition """
 
-from pydantic import BaseModel
+from rowantree.common.sdk import BaseModel
 
 
 class PopulationGetResponse(BaseModel):
